Documentation
¶
Overview ¶
Package rly provides an interface to the cosmos relayer running in a Docker container.
Index ¶
Constants ¶
const ( DefaultContainerImage = "ghcr.io/cosmos/relayer" DefaultContainerVersion = "v2.3.1" )
const (
RlyDefaultUidGid = "100:1000"
)
Variables ¶
This section is empty.
Functions ¶
func Capabilities ¶
func Capabilities() map[relayer.Capability]bool
Capabilities returns the set of capabilities of the Cosmos relayer.
Note, this API may change if the rly package eventually needs to distinguish between multiple rly versions.
Types ¶
type CosmosRelayer ¶
type CosmosRelayer struct {
// Embedded DockerRelayer so commands just work.
*relayer.DockerRelayer
}
CosmosRelayer is the ibc.Relayer implementation for github.com/cosmos/relayer.
func NewCosmosRelayer ¶
func NewCosmosRelayer(log *zap.Logger, testName string, cli *client.Client, networkID string, options ...relayer.RelayerOption) *CosmosRelayer
type CosmosRelayerChainConfig ¶
type CosmosRelayerChainConfig struct {
Type string `json:"type"`
Value CosmosRelayerChainConfigValue `json:"value"`
}
func ChainConfigToCosmosRelayerChainConfig ¶
func ChainConfigToCosmosRelayerChainConfig(chainConfig ibc.ChainConfig, keyName, rpcAddr, gprcAddr string) CosmosRelayerChainConfig
type CosmosRelayerChainConfigValue ¶
type CosmosRelayerChainConfigValue struct {
AccountPrefix string `json:"account-prefix"`
ChainID string `json:"chain-id"`
Debug bool `json:"debug"`
GRPCAddr string `json:"grpc-addr"`
GasAdjustment float64 `json:"gas-adjustment"`
GasPrices string `json:"gas-prices"`
Key string `json:"key"`
KeyringBackend string `json:"keyring-backend"`
OutputFormat string `json:"output-format"`
RPCAddr string `json:"rpc-addr"`
SignMode string `json:"sign-mode"`
Timeout string `json:"timeout"`
}
type RlyWallet ¶
type RlyWallet struct {
// contains filtered or unexported fields
}
func (*RlyWallet) FormattedAddress ¶
type WalletModel ¶
Click to show internal directories.
Click to hide internal directories.